@@ -3,7 +3,7 @@ package LWP::Protocol::UWSGI;
 use strict;
 use utf8;
 
-use version; our $VERSION = qv('v1.1.2');
+use version; our $VERSION = qv('v1.1.3');
 
 use HTTP::Response	qw( );
 use LWP::Protocol::http qw( );
@@ -146,7 +146,7 @@ sub request {
 	}
 
 	my $env = {};
-	$env->{QUERY_STRING}   = $1 if $fullpath =~ m,^[^?]+(?:\?(.*))?$,;
+	$env->{QUERY_STRING}   = $fullpath =~ m,^[^?]+(?:\?(.*))?$, ? $1 : '';
 	$env->{REQUEST_METHOD} = $method;
 	$env->{CONTENT_LENGTH} = defined $request_headers->header('Content-Length') ? $request_headers->header('Content-Length') : '';
 	$env->{CONTENT_TYPE}   = '';
